@@ -33,7 +33,7 @@
  *
  */
 
-/* $Id: adddicthelper.c,v 1.8 2002/11/09 16:56:47 famao Exp $ */
+/* $Id: adddicthelper.c,v 1.9 2003/02/19 17:44:50 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -232,9 +232,9 @@ main (int argc, char *argv[])
 	gchar *ustr;
 #endif
 #ifdef HAVE_SETENV
-	setenv ("LC_ALL", "ja_JP.eucJP", TRUE);
+	setenv ("LC_ALL", JA_LOCALE , TRUE);
 #elif HAVE_PUTENV
-	putenv ("LC_ALL=ja_JP.eucJP");
+	putenv ("LC_ALL=" JA_LOCALE);
 #endif
 	gtk_set_locale ();
 
