@@ -33,7 +33,7 @@
  *
  */
 
-/* $Id: codetable.c,v 1.9 2003/02/19 17:44:50 famao Exp $ */
+/* $Id: codetable.c,v 1.11 2003/04/01 22:18:46 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -49,6 +49,7 @@
 #include "codetable.h"
 #include "support.h"
 #include "config.h"
+#include "wmutil.h"
 
 #ifndef SKK_AUX_CODE_DEBUG
 #include "xaux_common.h"
@@ -90,20 +91,25 @@ static void prev_button_clicked (GtkWidget *widget, gpointer user_data);
 static void close_clicked (GtkWidget *widget, gpointer user_data);
 static void table_clicked (GtkWidget *widget, gpointer user_data);
 static void code_button_clicked (GtkWidget *widget, gpointer user_data);
-static GdkFilterReturn ext_event_handler (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer user_data);
+static GdkFilterReturn focus_hack_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer user_data);
 
 static GdkFilterReturn
-ext_event_handler (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer user_data)
+focus_hack_filter (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer user_data)
 {
 	XEvent *xevent;
+	GdkWindow *win = event->any.window;
+	static Atom take_focus = None;
+	static Atom wm_protocols = None;
+	if (wm_protocols == None)
+		wm_protocols = XInternAtom (GDK_WINDOW_XDISPLAY (win), "WM_PROTOCOLS", False);
+	if (take_focus == None)
+		take_focus = XInternAtom (GDK_WINDOW_XDISPLAY (win), "WM_TAKE_FOCUS", False);
 	xevent = (XEvent *) gdk_xevent;
 	if (xevent->type == ClientMessage) {
-#ifndef SKK_AUX_CODE_DEBUG
-		xaux_ext_process_client_message (GDK_DISPLAY (), (XClientMessageEvent *) xevent);
-#endif
-		return GDK_FILTER_REMOVE;
-	} else if (xevent->type == KeyRelease) {
-		return GDK_FILTER_REMOVE;
+		if (((Atom) xevent->xclient.message_type == wm_protocols) &&
+				((Atom) xevent->xclient.data.l[0] == take_focus)) {
+			return GDK_FILTER_REMOVE;
+		}
 	}
 	return GDK_FILTER_CONTINUE;
 }
@@ -349,7 +355,7 @@ skk_aux_code_table_new (gchar *label)
 	GtkWidget *button;
 	GtkWidget *vbox;
 	GtkWidget *buttonbox;
-	XWMHints hints;
+	GdkAtom type[1];
 	int x,y;
 
 	toplevel = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -406,13 +412,18 @@ skk_aux_code_table_new (gchar *label)
 	/* do not delete */
 	gtk_signal_connect (GTK_OBJECT (toplevel), "delete_event", 
 			GTK_SIGNAL_FUNC (conv_table_delete), NULL);
+	GTK_WIDGET_UNSET_FLAGS(toplevel, GTK_CAN_FOCUS);
 	gtk_widget_realize (toplevel);
+#if 0
 	gdk_window_add_filter (toplevel->window, ext_event_handler, 0);
+#endif
 	/* Set Hints */
-	memset (&hints, 0, sizeof (XWMHints));
-	hints.flags = InputHint;
-	hints.input = False;
-	XSetWMHints (GDK_DISPLAY (), GDK_WINDOW_XWINDOW (toplevel->window), &hints);
+	wmutil_window_input_icccm (toplevel->window, FALSE);
+	/* Set WIndow Type */
+	type[0] = gdk_atom_intern ("_NET_WM_WINDOW_TYPE_TOOLBAR", FALSE);
+	wmutil_window_type_ewmh (toplevel->window, type, 1, GDK_PROP_MODE_REPLACE);
+
+	gdk_window_add_filter (toplevel->window, focus_hack_filter, 0);
 	return toplevel;
 }
 
@@ -423,7 +434,7 @@ skk_aux_code_new (void)
 	GtkWidget *frame;
 	GtkWidget *vbox;
 	GtkWidget *button;
-	XWMHints hints;
+	GdkAtom type[1];
 
 	
 	toplevel = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -531,12 +542,17 @@ skk_aux_code_new (void)
 	/* do not destroy */
 	gtk_signal_connect (GTK_OBJECT (toplevel), "delete_event",
 			GTK_SIGNAL_FUNC (gtk_widget_hide_on_delete), NULL);
+#if 0
+	gdk_window_add_filter (toplevel->window, ext_event_handler, 0);
+#endif
 	gtk_widget_realize (toplevel);
 	/* set hints */
-	memset (&hints, 0, sizeof (XWMHints));
-	hints.flags = InputHint;
-	hints.input = False;
-	XSetWMHints (GDK_DISPLAY (), GDK_WINDOW_XWINDOW (toplevel->window), &hints);
+	wmutil_window_input_icccm (toplevel->window, FALSE);
+	/* set window type */
+	type[0] = gdk_atom_intern ("_NET_WM_WINDOW_TYPE_TOOLBAR", FALSE);
+	wmutil_window_type_ewmh( toplevel->window, type, 1, GDK_PROP_MODE_REPLACE);
+
+	gdk_window_add_filter (toplevel->window, focus_hack_filter, 0);
 	return toplevel;
 }
 
