@@ -34,7 +34,7 @@
  *
  */
 
-/* $Id: skk_xaux_so.c,v 1.1.1.1.2.1 2003/02/07 09:21:30 famao Exp $ */
+/* $Id: skk_xaux_so.c,v 1.2 2003/02/19 17:44:50 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -93,6 +93,10 @@ Sun Microsystems, Inc. or its licensors is granted.
 #include "xaux_common.h"
 #include "xaux_so_common.h"
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 extern aux_method_t xaux_so_methods;
 
 static const CARD16     aux_utfname_palette[] = {
@@ -113,26 +117,26 @@ static const CARD16     aux_utfname_adddict[] = {
 			'.','s','k','k','.', 'A','d','d','D','i','c','t','A','u','x',
 };
 
-#define		XAUX_EXT_DIR	"/usr/lib/im/locale/ja/skk/xaux/"
+/* #define		SKK_XAUX_EXT_DIR	"/usr/lib/im/locale/ja/skk/xaux/" */
 
 xaux_class_t xaux_classes[AUX_CLASS_MAX + 1] = {
 	{
 		"org.momonga-linux.skk.PaletteAux", 1,
-		XAUX_EXT_DIR "PaletteAux",
+		SKK_XAUX_EXT_DIR "PaletteAux",
 		(Window)0, (Window)0,
 		(Atom)0, (Atom)0, (Atom)0, { (Atom)0 }, 0, { (Atom)0 }, 0,
 		aux_utfname_palette,
 	},
 	{
 		"org.momonga-linux.skk.LookupAux", 2,
-		XAUX_EXT_DIR "LookupAux",
+		SKK_XAUX_EXT_DIR "LookupAux",
 		(Window)0, (Window)0,
 		(Atom)0, (Atom)0, (Atom)0, { (Atom)0 }, 0, { (Atom)0 }, 0,
 		aux_utfname_lookup,
 	},
 	{
 		"org.momonga-linux.skk.AddDictAux", 3,
-		XAUX_EXT_DIR "AddDictAux",
+		SKK_XAUX_EXT_DIR "AddDictAux",
 		(Window)0, (Window)0,
 		(Atom)0, (Atom)0, (Atom)0, { (Atom)0 }, 0, { (Atom)0 }, 0,
 		aux_utfname_adddict,
