@@ -34,7 +34,7 @@
  *
  */
 
-/* $Id: skkpalette.c,v 1.4 2003/02/19 17:44:50 famao Exp $ */
+/* $Id: skkpalette.c,v 1.10 2003/03/29 19:51:29 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -212,14 +212,17 @@ _ext_event_handler (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer user_data)
     } else if (xevent->type == KeyRelease) {
 	 //   key_event_handler(0, 0, xevent, 0);
 		    return GDK_FILTER_REMOVE;
-    } else if (xevent->type == ReparentNotify) {
+    } 
+#if 0
+    else if (xevent->type == ReparentNotify) {
 	    XReparentEvent *re = (XReparentEvent *)xevent;
 	    g_message ("ext reparent %lx %lx -> %lx",
 			    re->event,
 			    re->window,
 			    re->parent
 		      );
-    } else if (xevent->type == PropertyNotify) {
+    } 
+    else if (xevent->type == PropertyNotify) {
 	    XPropertyEvent *pe = (XPropertyEvent *)xevent;
 	    g_message ("ext property notify %lx %d %s",
 			    pe->window,
@@ -228,6 +231,7 @@ _ext_event_handler (GdkXEvent *gdk_xevent, GdkEvent *event, gpointer user_data)
 		      );
     }
     g_message ("ext type %d", xevent->type);
+#endif
     return GDK_FILTER_CONTINUE;
 }
 
@@ -379,6 +383,7 @@ _show_codetable (void)
 		gdk_window_raise (code->window);
 		return;
 	}
+	wmutil_window_input_icccm (code->window, FALSE);
 	gtk_widget_show (code);
 	/* TODO need it ? */
 	gdk_window_raise (code->window);
@@ -397,7 +402,6 @@ _reply_initialize (void)
 Bool
 xaux_ext_Start (xaux_class_t *xc, aux_ext_data_t *aux_ext_data)
 {
-	g_message ("ext_Start");
 #if 0
 	gtk_widget_show (SKK_PALETTE_WIDGET (g_palette));
 	gdk_window_raise (SKK_PALETTE_WINDOW (g_palette));
@@ -410,7 +414,7 @@ xaux_ext_Start (xaux_class_t *xc, aux_ext_data_t *aux_ext_data)
 Bool
 xaux_ext_Done (xaux_class_t *xc, aux_ext_data_t *aux_ext_data)
 {
-	g_message ("ext_Done");
+	gtk_main_quit ();
 	return True;
 }
 
@@ -424,7 +428,6 @@ xaux_ext_Draw (xaux_class_t *xc, aux_ext_data_t *aux_ext_data)
 	xc_ = xc;
 
 	if (!GTK_WIDGET_VISIBLE (SKK_PALETTE_WIDGET (g_palette))) {
-		g_message ("Draw palette_show");
 		palette_show (SKK_PALETTE (g_palette));
 	}
 #if 0
@@ -537,27 +540,30 @@ skk_aux_palette_send_engine (gint int_count, gint *integers, gint str_count, gch
 static gboolean
 _handle_wm (Palette *palette, gint wm_type, gint new_detected)
 {
-	g_message ("_handle_wm");
 #if 0
 	gtk_widget_hide (PALETTE_WIDGET (palette));
 #endif
 	gdk_window_set_override_redirect (PALETTE_WINDOW (palette), FALSE);
 	if (wm_type & WM_IS_BLACKBOX) {
-		g_message ("withdraw");
+		g_message ("BlackBox compliant WM is found");
+		g_message ("add WithDrawn state to Palette");
+		gtk_widget_hide (PALETTE_WIDGET (palette));
 		wmutil_window_hints_icccm (PALETTE_WINDOW (palette), WithdrawnState);
 		gtk_widget_show (PALETTE_WIDGET (palette));
 		return TRUE;
 	}
 	if (wm_type & WM_IS_EWMH) {
+		g_message ("EWMH compliant WM is found");
 		gtk_widget_hide (PALETTE_WIDGET (palette));
 		_ewmh_hints (palette, wm_type);
 	}
 	if (wm_type & WM_IS_GNOME) {
+		g_message ("old GNOME compliant WM is found");
 		gtk_widget_hide (PALETTE_WIDGET (palette));
 		_gnome_hints (palette, wm_type);
 	}
 	gtk_widget_show (PALETTE_WIDGET (palette));
-#if 0
+#if 1
 	if (wm_type & WM_IS_EWMH) {
 		_ewmh_hints (palette, wm_type);
 	}
@@ -568,13 +574,13 @@ _handle_wm (Palette *palette, gint wm_type, gint new_detected)
 static gboolean
 _handle_tray (Palette *palette, gint tray_type, gint new_detected)
 {
-	g_message ("_handle_tray");
-#if 1
+#if 0
 	tray_window_set_parent (SKK_TRAY (g_palette), SKK_PALETTE_WIDGET (g_palette));
 #endif
 	tray_window_realize (SKK_TRAY (g_palette));
 	gtk_widget_set_name (SKK_TRAY(g_palette)->window, "skk-tray");
 	if (tray_type & WM_IS_EWMH) {
+		g_message ("EWMH compliant Tray is found");
 		_ewmh_hints_tray (SKK_TRAY (g_palette), tray_type);
 	}
 	if (tray_type & WM_IS_GNOME) {
@@ -704,14 +710,18 @@ _ewmh_hints (Palette *palette, gint wm_type)
 	 * when use metacity, we need to set 
 	 * _NET_WM_WINDOW_TYPE_DOCK or _NET_WM_WINDOW_TYPE_DESKTOP for sticky option
 	 */
+#if 0
 	if (!(wm_type & WM_IS_KWIN)) {
 		docked_ewmh[0] = gdk_atom_intern ("_NET_WM_WINDOW_TYPE_DOCK", FALSE);
 	} else {
 		/*
 		 * kwin 3.x has trouble with NET_WM_WINDOW_TYPE
+		 * 3.1 is ok?
 		 */
-		docked_ewmh[0] = gdk_atom_intern ("_NET_WM_WINDOW_TYPE_BUGGY", FALSE);
+		docked_ewmh[0] = gdk_atom_intern ("_NET_WM_WINDOW_TYPE_DOCK", FALSE);
 	}
+#endif
+	docked_ewmh[0] = gdk_atom_intern ("_NET_WM_WINDOW_TYPE_DOCK", FALSE);
 
 	if (GTK_WIDGET_VISIBLE (PALETTE_WIDGET (palette))) {
 		wmutil_window_state_ewmh_client_message (PALETTE_WINDOW (palette),
