@@ -34,7 +34,7 @@
  *
  */
                                                                                                           
-/* $Id: skktray.c,v 1.2 2003/02/19 17:44:50 famao Exp $ */
+/* $Id: skktray.c,v 1.3 2003/03/13 14:10:15 famao Exp $ */
                                                                                                           
 /* vi:set ts=4 sw=4: */
 
@@ -104,7 +104,7 @@ static gint
 _tray_leave (GtkWidget *widget, GdkEventAny *event, gpointer user_data)
 {
 	g_message ("focus_out");
-	wmutil_window_tray_baloon_start (widget->window, 0, message_id);
+	wmutil_window_tray_baloon_cancel (widget->window, message_id);
 	message_id++;
 	return FALSE;
 }
@@ -148,9 +148,12 @@ _create_window (TrayWindow *tray)
 	GtkWidget *button;
 	GtkWidget *icon;
 
-	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	/* window = gtk_window_new (GTK_WINDOW_TOPLEVEL); */
+	window = gtk_plug_new (0);
 	icon = pixmap_new_with_xpm (window, tray_xpm);
 	button = pixmap_button_new (NULL, icon);
+	gtk_plug_construct (GTK_PLUG (window), 0);
+	gtk_widget_realize (window);
 	gtk_container_add (GTK_CONTAINER (window), button);
 	gtk_container_set_resize_mode (GTK_CONTAINER (button), GTK_RESIZE_PARENT);
 	gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
