@@ -34,7 +34,7 @@
  *
  */
                                                                                                           
-/* $Id: tray.c,v 1.2 2003/02/19 17:44:50 famao Exp $ */
+/* $Id: tray.c,v 1.5 2003/03/14 02:32:47 famao Exp $ */
                                                                                                           
 /* vi:set ts=4 sw=4: */
 
@@ -141,8 +141,8 @@ tray_window_show (TrayWindow *tray)
 	if (!tray->window)
 		return;
 	tray->wm_mask = wmutil_window_check_wm_type ();
-	g_message ("wm_mask %dx", tray->wm_mask);
-	if (tray->wm_mask & WM_IS_KWIN) {
+#if 0
+	if ((tray->wm_mask & WM_IS_KWIN)) {
 		g_message ("Entering KDE Tray");
 		if (tray->parent) {
 			wmutil_window_tray_kde (tray->window->window, tray->parent->window);
@@ -150,22 +150,25 @@ tray_window_show (TrayWindow *tray)
 			wmutil_window_tray_kde (tray->window->window, GDK_ROOT_PARENT ());
 		}
 	}
+#endif
 #if 0
 	if (tray->wm_mask & WM_IS_ICEWM) {
 		g_message ("Entering ICEWM Tray");
 		wmutil_window_tray_icewm (tray->window->window, ICEWM_TRAY_MINIMIZED);
 	}
 #endif
-	if (tray->wm_mask & WM_CAN_TRAY_SPEC) {
+#if 0
+	if ((tray->wm_mask & WM_CAN_TRAY_SPEC) && !(tray->wm_mask & WM_IS_KWIN)) {
 		g_message ("Entering EWMH Tray");
 		wmutil_window_tray_xembed (tray->window->window);
 		wmutil_window_tray_spec (tray->window->window);
 	}
+#endif
 	gdk_window_set_decorations (tray->window->window, 0);
 	gtk_widget_show (tray->window);
 	gdk_window_add_filter (tray->window->window, _tray_event_filter, (gpointer) tray);
 #if 1
-	if (tray->wm_mask & WM_CAN_TRAY_SPEC) {
+	if (((tray->wm_mask & WM_CAN_TRAY_SPEC))) {
 		g_message ("Entering EWMH Tray");
 		wmutil_window_tray_xembed (tray->window->window);
 		wmutil_window_tray_spec (tray->window->window);
@@ -213,11 +216,13 @@ tray_window_set_xembed_event_handler (TrayWindow *tray, XEmbedEventHandler handl
 static GtkWidget *
 create_win (TrayWindow *tray)
 {
-	GtkWidget *w = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	GtkWidget *plug = gtk_plug_new (0);
 	GtkWidget *button = gtk_button_new_with_label ("test");
+	gtk_plug_construct (GTK_PLUG (plug), 0);
 	gtk_widget_show (button);
-	gtk_container_add (GTK_CONTAINER (w), button);
-	return w;
+	gtk_widget_realize (plug);
+	gtk_container_add (GTK_CONTAINER (plug), button);
+	return plug;
 }
 
 int
