@@ -33,7 +33,7 @@
  *
  */
 
-/* $Id: xaux_ext_common.c,v 1.5 2003/02/19 17:44:50 famao Exp $ */
+/* $Id: xaux_ext_common.c,v 1.6 2003/03/29 19:51:29 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -83,19 +83,35 @@ Sun Microsystems, Inc. or its licensors is granted.
 */
 
 /*
- * $Id: xaux_ext_common.c,v 1.5 2003/02/19 17:44:50 famao Exp $
+ * $Id: xaux_ext_common.c,v 1.6 2003/03/29 19:51:29 famao Exp $
  * Modified by Motonobu Ichimura <famao@kondara.org>
  */
 
 #pragma ident	"@(#)xaux_ext_common.c 1.21 99/12/08"
 
-#include <locale.h>
-#include <stdlib.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+#ifdef HAVE_LIMITS_H
 #include <limits.h>
+#endif
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_WAIT_H
 #include <sys/wait.h>
+#endif
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
 
 #include <X11/X.h>
 #include <X11/Xatom.h>
@@ -107,9 +123,6 @@ Sun Microsystems, Inc. or its licensors is granted.
 #include "xaux_common.h"
 #include "xaux_ext_common.h"
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 
 static Bool xaux_xs_send_message (Display *display, xaux_class_t *xc, int im_id, int ic_id,
 		aux_ext_data_type_t type, Atom atom);
@@ -1222,7 +1235,7 @@ IIimpConvertFromUTF16(char *from_buf, size_t from_left,
 
   if (i_conv2_FromUTF16 == NULL && !skip_native_to_utf8_conv) {
 #ifdef HAVE_LANGINFO_CODESET
-    char *encoding = nl_langinfo(CODESET);
+	char *encoding = nl_langinfo(CODESET);
 #else
 	char *encoding = "EUC-JP";
 #endif
