@@ -33,7 +33,7 @@
  *
  */
 
-/* $Id: xaux_so_common.c,v 1.4 2003/02/19 17:44:50 famao Exp $ */
+/* $Id: xaux_so_common.c,v 1.5 2003/03/29 19:51:29 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -83,22 +83,41 @@ Sun Microsystems, Inc. or its licensors is granted.
 */
 
 /*
- * $Id: xaux_so_common.c,v 1.4 2003/02/19 17:44:50 famao Exp $
- * Modified by Motonobu Ichimura <famao@kondara.org>
+ * $Id: xaux_so_common.c,v 1.5 2003/03/29 19:51:29 famao Exp $
+ * Modified by Motonobu Ichimura <famao@momonga-linux.org>
  */
 
 #pragma ident	"@(#)xaux_so_common.c 1.37 99/12/20"
 
-#include <stddef.h>
-#include <stdlib.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
+#ifdef HAVE_STDDEF_H
+#include <stddef.h>
+#endif
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_WAIT_H
+#include <sys/wait.h>
+#endif
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_LIMITS_H
 #include <limits.h>
+#endif
 #if 0
 #include <libgen.h>
 #endif
+#ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
+#endif
 
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
@@ -108,7 +127,6 @@ Sun Microsystems, Inc. or its licensors is granted.
 #include "xaux_common.h"
 #include "xaux_so_common.h"
 
-#include "config.h"
 
 extern xaux_class_t xaux_classes[];
 
@@ -229,6 +247,7 @@ xaux_so_launch_ext(
 	aux_t		*aux
 )
 {
+	int		status;
 	pid_t		pid;
 	const char	*ext = xc->extexec;
 
@@ -262,7 +281,7 @@ xaux_so_launch_ext(
 		return False;
 	}
 			
-#ifdef	sun
+#ifdef	HAVE_FORK1
 	pid = fork1();
 #else
 	pid = fork();
@@ -274,10 +293,22 @@ xaux_so_launch_ext(
 #if defined(DEBUG_XAUX)
 		chdir("/tmp");
 #endif /* defined(DEBUG_XAUX) */
-		execl(ext, xc->classname, NULL);
-		_exit(1);
+#ifdef HAVE_FORK1
+		pid = fork1();
+#else
+		pid = fork();
+#endif
+		if (pid == (pid_t)(-1)) { /* fork failed */
+			return False;
+		} else if (0 == pid) { /* child */
+			execl(ext, xc->classname, NULL);
+			_exit(1);
+		}
+		_exit (0);
 	}
-	
+
+	/* TODO */
+	wait (&status);
 	/* parent */
 	return True;
 }
