@@ -33,7 +33,7 @@
  *
  */
 
-/* $Id: skkbuffer.c,v 1.27 2003/02/19 17:44:51 famao Exp $ */
+/* $Id: skkbuffer.c,v 1.28 2004/04/23 07:20:57 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -235,15 +235,9 @@ separate_string_by_cursor (SkkBuffer *buf, const gchar *string, gchar **beforep,
 		after += offset;
 		if (beforep) {
 			*beforep = g_strndup (string, offset);
-#if 0
-			g_message ("beforep %s", *beforep);
-#endif
 		}
 		if (afterp) {
 			*afterp = g_strdup (after);
-#if 0
-			g_message ("after %s", after);
-#endif
 		}
 		return TRUE;
 	}
@@ -349,9 +343,6 @@ preedit_emit (SkkBuffer *buf)
 		if (skkbuf_cursor (buf)->caret == 0) {
 			skkbuf_cursor (buf)->revLen = skkbuf_plen (buf);
 		}
-#if 0
-		g_message ("revLen %d", skkbuf_cursor (buf)->revLen);
-#endif
 	} else {
 		skkbuf_cursor (buf)->revPos = 0;
 		skkbuf_cursor (buf)->revLen = 0;
