@@ -32,7 +32,7 @@
  *
  */
 
-/* $Id: skkdictitem.c,v 1.4 2003/02/19 17:44:51 famao Exp $ */
+/* $Id: skkdictitem.c,v 1.5 2004/05/03 04:23:49 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -67,25 +67,61 @@ skk_dict_item_new_with_string (const gchar *string, const gchar *delim)
 	gchar *sep;
 	gchar *copy;
 	SkkDictItem *ret;
+	gsize delim_len;
 	if (!string)
 		return skk_dict_item_new ();
-	if (!delim) {
+	if (!delim || !*delim) {
 		return skk_dict_item_new_with_value (string, NULL);
 	}
 	copy = g_strdup (string);
 	sep = strstr (copy, delim);
+	delim_len = strlen (delim);
 	if (!sep) {
 		g_free (copy);
 		return skk_dict_item_new_with_value (string, NULL);
 	} else {
 		*sep = '\0';
-		sep += strlen (delim);
+		sep += delim_len;
 	}
 	ret = skk_dict_item_new_with_value ((const gchar*) copy, sep);
 	g_free (copy);
 	return ret;
 }
 
+GList *
+skk_dict_item_new_from_line (const gchar *line, const gchar *delim, const gchar *annotate_delim)
+{
+	GList *ret = NULL;
+	gchar *tmp, *first;
+	gchar *p;
+	gsize delim_len;
+	if (!line)
+		return NULL;
+	if (!delim || !*delim)
+		return NULL;
+
+	delim_len = strlen (delim);
+	first = tmp = g_strdup (line);
+	p = strstr (first, delim);
+	if (p) {
+		while (p) {
+			*p = '\0';
+			if (p - tmp >0)
+				ret = g_list_append (ret, skk_dict_item_new_with_string (tmp, annotate_delim));
+			tmp = p + delim_len;
+			p = strstr (tmp, delim);
+		}
+	}
+	if (*tmp) {
+		p = strchr (tmp, '\n');
+		if (p)
+			*p = '\0';
+		ret = g_list_append (ret, skk_dict_item_new_with_string (tmp, annotate_delim));
+	}
+	g_free (first);
+	return ret;
+}
+
 void
 skk_dict_item_destroy (SkkDictItem *item)
 {
