@@ -32,7 +32,7 @@
  *
  */
 
-/* $Id: skkdictitem.h,v 1.4 2003/02/19 17:44:51 famao Exp $ */
+/* $Id: skkdictitem.h,v 1.5 2004/05/03 04:23:49 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -48,11 +48,13 @@ struct _SkkDictItem
 {
 	gchar *candidate;
 	gchar *annotation;
+	guint flag;
 };
 
 SkkDictItem *skk_dict_item_new (void);
 SkkDictItem *skk_dict_item_new_with_value (const gchar *candidate, const gchar *annotation);
 SkkDictItem *skk_dict_item_new_with_string (const gchar *string, const gchar *delim);
+GList *skk_dict_item_new_from_line (const gchar *line, const gchar *delim, const gchar *annotate_delim);
 void skk_dict_item_destroy (SkkDictItem *item);
 void skk_dict_item_destroy_all (GList *list);
 GList *skk_dict_item_merge_list (GList *list1, GList *list2);
