@@ -33,7 +33,7 @@
  *
  */
                                                                                                                                        
-/* $Id: skkdictutil.c,v 1.3 2003/02/19 17:44:51 famao Exp $ */
+/* $Id: skkdictutil.c,v 1.4 2004/04/23 07:20:57 famao Exp $ */
                                                                                                                                        
 /* vi:set ts=4 sw=4: */
 
@@ -50,7 +50,6 @@ skk_dict_util_encode_string (const gchar *str)
 	g_message ("dict_util_encode");
 	if (!str)
 		return NULL;
-	g_message ("dict_util_encode %s", str);
 	while (*p != '\0') {
 		switch (*p) {
 			case '\r':
@@ -126,7 +125,6 @@ skk_dict_util_encode_string (const gchar *str)
 	memcpy (q, "\")", 2);
 	q+=2;
 	*q = '\0';
-	g_message ("ret %s", ret);
 	return ret;
 }
 
@@ -139,7 +137,6 @@ skk_dict_util_decode_string (const gchar *str)
 	g_message ("dict_util_decode");
 	if (!str)
 		return NULL;
-	g_message ("dict_util_decode %s", str);
 	if (strncmp (str, "(concat \"", 9)) {
 		return g_strdup (str);
 	}
@@ -180,7 +177,6 @@ skk_dict_util_decode_string (const gchar *str)
 		}
 	}
 	*q++ = '\0';
-	g_message ("ret %s", ret);
 	return ret;
 }
 
