@@ -34,7 +34,7 @@
  *
  */
 
-/* $Id: skk.c,v 1.18 2003/02/19 17:44:53 famao Exp $ */
+/* $Id: skk.c,v 1.24 2004/04/23 07:20:57 famao Exp $ */
 
 /* vi:set ts=4 sw=4: */
 
@@ -81,6 +81,10 @@ Sun Microsystems, Inc. or its licensors is granted.
 
 */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -207,7 +211,7 @@ static void skk_aux_dict_draw (iml_session_t *s, const gchar *query_str);
 static void skk_start_conversion (iml_session_t *s);
 static void skk_end_conversion (iml_session_t *s);
 
-#define skk_aux_status_done(s) skk_aux_done ((s), SKK_AUX_PALETTE_CLASS_NAME)
+#define skk_aux_palette_done(s) skk_aux_done ((s), SKK_AUX_PALETTE_CLASS_NAME)
 #define skk_aux_dict_done(s) skk_aux_done ((s), SKK_AUX_ADD_DICT_CLASS_NAME)
 static void skk_aux_done (iml_session_t *s, char *class_name);
 static void skk_aux_draw (iml_session_t *s, char *class_name, int int_count, int *integers,
@@ -271,13 +275,13 @@ static SkkBuffer *skk_session_buf (iml_session_t *s);
 static SkkSessionData *
 skk_session_data (iml_session_t * s)
 {
-	return (SkkSessionData *) (s->specific_data);
+	return s ? (SkkSessionData *) (s->specific_data) : NULL;
 }
 
 static SkkDesktopData *
 skk_desktop_data (iml_session_t *s)
 {
-	return (SkkDesktopData *) (s->desktop->specific_data);
+	return s ? (SkkDesktopData *) (s->desktop->specific_data): NULL;
 }
 
 static SkkBuffer *
@@ -623,6 +627,11 @@ static Bool
 if_skk_CloseDesktop (iml_desktop_t * desktop)
 {
 	SkkDesktopData *d = (SkkDesktopData *)desktop->specific_data;
+#if 0
+	iml_session_t *s = (iml_session_t *)desktop->session_list;
+	SkkSessionData *ses = skk_session_data (s);
+#endif
+
 #ifdef DEBUG
 	printf ("if_skk_CloseDesktop()\n");
 	printf ("	This method is invoked when the user exits from\n");
@@ -657,6 +666,16 @@ if_skk_CloseDesktop (iml_desktop_t * desktop)
 	if (d->skkconv) {
 		skk_conv_rule_destroy (d->skkconv);
 	}
+
+#if 0
+	/* FAMAO session_data is already NULL'd. */
+	if (ses) {
+		if (ses->dict_aux_ok)
+			skk_aux_dict_done (s);
+		if (ses->palette_aux_ok)
+			skk_aux_palette_done (s);
+	}
+#endif
 	g_free (d);
 	return True;
 }
@@ -977,18 +996,27 @@ static void
 skk_commit_imtext (iml_session_t *s, IMText *text)
 {
 	iml_inst *lp;
+#if 0
 	SkkSessionData *ses = skk_session_data (s);
+#endif
 	if (!text)
 		return;
 
+#if 0
 	/* erase preedit area first */
 	if (ses->preedit_start == True) {
 		skk_preedit_clear (s);
 		ses->preedit_start = False;
 	}
+#endif
 	/* commit string */
 	lp = s->If->m->iml_make_commit_inst (s, text);
 	s->If->m->iml_execute (s, &lp);
+
+#if 0
+	/* BUG workaround */
+	skk_preedit_clear (s);
+#endif
 }
 
 static void
@@ -1195,7 +1223,7 @@ skk_translate_keyevent_luc (iml_session_t *s, IMKeyListEvent *kev)
 				buf->candidate_count = 0;
 				skk_lookup_choice_done (s);
 				skk_buffer_undo (buf);
-				return SKK_TRANS;
+				return SKK_NOTHING;
 			}
 			break;
 		case IM_VK_X:
@@ -1302,25 +1330,6 @@ static void
 skk_process_keyevent_jmode (iml_session_t *s, IMKeyListEvent *kev)
 {
 	SkkBuffer *buf = skk_session_buf (s);
-	DEBUG_DO (printf ("skk_process_keyevent_jmode\n"));
-	DEBUG_DO (g_message ("skkbuf result (%s)\n", skkbuf_r (buf)));
-	DEBUG_DO (g_message ("skkbuf preedit (%s)\n", skkbuf_p (buf)));
-	DEBUG_DO (g_message ("skkbuf direction_word (%s)\n", skkbuf_d (buf)));
-	DEBUG_DO (g_message ("skkbuf in_buf (%s)\n", skkbuf_b (buf)));
-	#if 0
-	if (skk_buffer_can_commit (buf)) {
-		skk_commit_string (s, skkbuf_r (buf));
-		/* once commit */
-	}
-	if (skk_buffer_has_preedit (buf)) {
-		gchar *preedit = skk_buffer_get_preedit_string (buf);
-		skk_preedit_clear (s);
-		skk_preedit_draw (s,preedit);
-		g_free (preedit);
-	} else {
-		skk_preedit_clear (s);
-	}
-	#endif
 	if (skk_buffer_can_clear (buf)) {
 		skk_buffer_clear (buf);
 	}
@@ -1390,6 +1399,8 @@ skk_process_keyevent (iml_session_t * s, IMKeyListEvent * kev)
 		case SKK_LATIN_MODE:
 			skk_commit_key (s,kev);
 			break;
+		default:
+			break;
 	}
 	return;
 }
@@ -1724,8 +1735,6 @@ skk_preedit_draw (iml_session_t *s, unsigned char *str)
 		strs[0] = str;
 		strs[1] = str + cursor->revPos;
 		strs[2] = str + cursor->revPos + cursor->revLen;
-		g_message ("%s %s %s %d %d %d", strs[0], strs[1], strs[2],
-				nb[0], nb[1], nb[2]);
 		if (nb[2] == 0) {
 			p = skk_strtoimtext (s, 2, nb, strs, fts);
 		} else {
@@ -1746,8 +1755,6 @@ skk_preedit_draw (iml_session_t *s, unsigned char *str)
 		strs[0] = str;
 		strs[1] = str + strlen (str) - cur;
 		strs[2] = str + nb[0] +  nb[1];
-		g_message ("caret %s %s %s %d %d %d", strs[0], strs[1], strs[2],
-				nb[0], nb[1], nb[2]);
 		if (nb[2] == 0) {
 			p = skk_strtoimtext (s, 2, nb, strs, fts);
 		} else {
@@ -1795,9 +1802,11 @@ skk_preedit_clear (iml_session_t *s)
 		iml_inst *lp;
 		lp = s->If->m->iml_make_preedit_erase_inst (s);
 		s->If->m->iml_execute (s,&lp);
+#if 0
 		lp = s->If->m->iml_make_preedit_done_inst (s);
 		s->If->m->iml_execute (s,&lp);
 		ses->preedit_start = False;
+#endif
 	}
 }
 
@@ -2302,13 +2311,27 @@ skk_status_done (iml_session_t *s)
 static Bool
 skk_drop_privilege (const char *username)
 {
+
+#ifndef NSS_BUFLEN_PASSWD
+#define NSS_BUELEN_PASSWD 1024
+#endif
+
+#ifdef HAVE_GETPWNAM_R
+	struct passwd pw_buf;
+	char buf[NSS_BUFLEN_PASSWD];
+#endif
 	struct passwd *pw;
 	uid_t uid;
 	gid_t gid;
 	if (!username)
 		goto error;
+#ifdef HAVE_GETPWNAM_R
+	if ((getpwnam_r (username, &pw_buf, buf, NSS_BUFLEN_PASSWD, &pw) != 0)) {
+		goto error;
+#else
 	if ((pw = getpwnam (username)) == NULL) {
 		goto error;
+#endif
 	} else {
 		uid = pw->pw_uid;
 		gid = pw->pw_gid;
@@ -2330,7 +2353,11 @@ skk_drop_privilege (const char *username)
 	return True;
 
 error:
+#ifdef HAVE_GETPWNAM_R
+	if ((getpwnam_r ("nobody", &pw_buf, buf, NSS_BUFLEN_PASSWD, &pw) == 0)) {
+#else
 	if ((pw = getpwnam ("nobody")) != NULL) {
+#endif
 		gid = pw->pw_gid;
 		uid = pw->pw_uid;
 		if (setregid (gid, gid) < 0) {
